********************************************************************************
*                                                                              *
*   PROGRAM: fltcable.for                                                      *
*                                                                              *
*   PURPOSE: Example of creating input data files                              *
*                                                                              *
********************************************************************************

	program fltcable

c	Create input data for analysis of a flat cable (file lparin.dat)
c	See Section 8.12 of User's Manual, and Figure 8.11

c	Data are compatible with kernel programs S1.DLL and S2.DLL

c	Insulated wires have the same cross section and are
c		equispaced in one layer, with touching coatings
c	Wires can be enclosed by a rectangular shield (box);
c		the reference conductor is the shield, if it is present;
c		otherwise, the last wire is the reference conductor
c	Box floor and ceiling are touching the wire coatings
c	Numbers of pulses are automatically determined

	implicit none
	integer nw,nwmax,n,nd,nsw,nst,nconst
	integer iw,i,k,ishield
	real a,d,epsr
	real pi,b,da,x0,y0,alpha,sw,st
	character*1 shield
	parameter (nwmax=20)
	parameter (nconst=16)

c	nw - number of wires
c	nwmax - maximal number of wires (it must not exceed maximal number
c		of conductors, 30, in the analysis program)
c	n - number of pulses for each wire
c	nd - number of pulses for each coating
c	nsw - number of pulses for box floor/ceiling
c	nst - number of pulses for each box side wall
c	shield - shield presence indicator
c	nconst - constant determining the accuracy of computations;
c		it must not be smaller than 3
c	a - wire radius
c	d - dielectric coating thickness
c	epsr - dielectric coating relative permittivity
c	all dimensions are input in meters

********************************************************************************

c	Get input data from the default input device (keyboard)
c	Numbers are entered in a free format

c	Get number of wires (1 to 20)

	write(*,*)
	call input_integer(
     1	'Number of wires (1 to 20)?',nw,1,nwmax)

c	Get wire radius (1.e-6 to 1. m)

	call input_real(
     1	'Wire radius [m]?',a,1.e-6,1.)

c	Get wire coating thickness (1.e-6 to 1. m)

	call input_real(
     1	'Coating thickness [m]?',d,1.e-6,1.)

c	Get wire coating relative permittivity (1. to 1.e3)

	call input_real(
     1	'Coating relative permittivity?',epsr,1.,1.e3)

c	If epsr=1.0, no pulses are defined for coatings, as wires are
c		located in vacuum

c	Define if the shield is present or not

	write(*,101)'Is the cable shielded (yes/no)?'
101	format(1x,a,' ',$)
	read(*,102)shield
102	format(a1)
	if(shield.eq.'y'.or.shield.eq.'Y') then
	  ishield=1
	else
	  ishield=0
	end if

c	end of input

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

	pi=4.*atan(1.)

c	automatic evaluation of the number of pulses

	b=a+d
	if(b.lt.1.02*a) b=1.02*a
	sw=2*nw*b
	st=2.*b

c	b - coating radius
c	sw - box width
c	st - box height

	n=nconst
	if(epsr.gt.1.) then
	  nd=nconst
	else
	  nd=0
	end if
	nsw=ishield*(nconst*sw/(pi*(a+b))+1.)
	nst=ishield*(nconst*st/(pi*(a+b))+1.)

c	prepare input data for the analysis program

	open(file='fltcable.iu1',unit=1)

	write(1,*)nw*(n+nd)+2*(nsw+nst)
	write(1,*)nw+ishield-1
	do iw=1,nw
	  write(1,*)n
	end do
	if(ishield.ne.0) write(1,*)2*(nsw+nst)
	write(1,*)nw*nd

c	define nodes for wires

	da=2.*pi/n
	y0 = b
	do iw=1,nw
	  x0=(2*iw-1)*b
	  do i=1,n
	    alpha=da*(i-1)
	    write(1,*)x0+a*cos(alpha),y0+a*sin(alpha)
	  end do
	end do

c	define nodes for shield

	if(ishield.ne.0) then
	  da=sw/nsw
	  do i=1,nsw
	    write(1,*)i*da,0.
	  end do
	  da=st/nst
	  do i=1,nst
	    write(1,*)sw,i*da
	  end do
	  da=sw/nsw
	  do i=nsw-1,0,-1
	    write(1,*)i*da,st
	  end do
	  da=st/nst
	  do i=nst-1,0,-1
	    write(1,*)0,i*da
	  end do
	end if

c	define nodes for coatings

	if(epsr.ne.1.) then
	  da=2.*pi/nd
	  y0=b
	  do iw=1,nw
	    x0=(2*iw-1)*b
	    do i=1,nd
	      alpha=da*(i-1)
	      write(1,*)x0+b*cos(alpha),y0+b*sin(alpha)
	    end do
	  end do
	end if

	k=1

c	define segments for wires

	do iw=1,nw
	  do i=1,n-1
	    write(1,*)k,k+1,epsr,1.
	    k=k+1
	  end do
	  write(1,*)k,k+1-n,epsr,1.
	  k=k+1
	end do

c	define segments for shield

	if(ishield.ne.0) then
	  do i=1,2*(nsw+nst)-1
	    write(1,*)k,k+1,1,1
	    k=k+1
	  end do
	  write(1,*)k,k+1-2*(nsw+nst),1.,1.
	  k=k+1
	end if

c	define segments for coatings

	if(epsr.ne.1.) then
	  do iw=1,nw
	    do i=1,nd-1
	      write(1,*)k,k+1,1.,epsr
	      k=k+1
	    end do
	    write(1,*)k,k+1-nd,1.,epsr
	    k=k+1
	  end do
	end if

	close(1)

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

c	terminate program

	end



****************************
*                          *
* subroutine input_integer *
*                          *
****************************

	subroutine input_integer(text,var,min,max)

c	input integer number

	implicit none
	character*(*) text
	integer var,min,max

1	write(*,101)text
101	format(1x,a,' ',$)
	read(*,*,err=2)var
	if(var.ge.min.and.var.le.max) go to 3
2	write(*,102)
102	format(' Illegal value. Please try again!')
	go to 1
3	continue
	write(*,*)

	return
	end



*************************
*                       *
* subroutine input_real *
*                       *
*************************

	subroutine input_real(text,var,min,max)

c	input real number

	implicit none
	character*(*) text
	real var,min,max

1	write(*,101)text
101	format(1x,a,' ',$)
	read(*,*,err=2)var
	if(var.ge.min.and.var.le.max) go to 3
2	write(*,102)
102	format(' Illegal value. Please try again!')
	go to 1
3	continue
	write(*,*)

	return
	end
